==> ikapi-1.0.5.tgz: package/src/Mailer/IKMailer.js <==
import { SES } from 'aws-sdk';
//
const nodemailer = require("nodemailer");
const path = require("path");
const AWS = require('aws-sdk');
const Email = require('email-templates');
//
import Utils from "./../API/IKUtils";
//
export default class IKMailer {
  constructor(_defaultFrom, region) {
    this.from = _defaultFrom;
    this.templateDefaultFile = 'html';
    //setup local stuff
    let configObj = {region: region};
    if (Utils.isOffline()) configObj = {region: region, accessKeyId: process.env.AWS_ACCESS_KEY_ID, secretAccessKey: process.env.AWS_SECRET_ACCESS_KEY};
    AWS.config.update(configObj);
    //
    this.transporter = nodemailer.createTransport({
      SES: new AWS.SES({ apiVersion: "2010-12-01" })
    });
  }

  //to can be an array or just one address
  async sendTemplatedEmail(_to, _templates, _data, _optionalCC, _optionalAttachments) {
    //Generate emails
    const email = new Email({
      message: {
        from: this.from,
        to: _to,
        ...(_optionalAttachments ? {attachments: _optionalAttachments} : {}),
        ...(_optionalCC ? {cc: _optionalCC} : {})
      },
      transport: this.transporter,
      send: true,
    });
    //
    let resp = null;
    try {
      const choosenTemplate = await this._chooseTemplate(_templates);
      resp = await email.send({template: choosenTemplate, locals: _data});
      // console.debug('Mailer resp:', resp);
    } catch (e) { console.error('Mailer error:', e); }
    return resp;
  }


  /* private */
  async _chooseTemplate(templates, data) {
    if (Array.isArray(templates)) {
      //For each template check if can render it
      for (let template of templates) {
        if (await this._canRenderTemplate(template, data)) return template;
      }
    } else if (templates) {
      if (await this._canRenderTemplate(templates, data)) return templates;
    } return 'raw'; //default fallback email
  }
  async _canRenderTemplate(template, data) {
    let validRenderResp = null;
    try {
      const email = new Email();
      validRenderResp = await email.render(`${template}/${this.templateDefaultFile}`, data);
    } catch (e) {
      console.log(`Error while checking renderability of email template ${template}`, e);
    } return (validRenderResp != null);
  }
}

==> ikapi-1.0.7.tgz: package/src/Mailer/IKMailer.js <==
import { SES } from 'aws-sdk';
//
const nodemailer = require("nodemailer");
const path = require("path");
const AWS = require('aws-sdk');
const Email = require('email-templates');
//
import Utils from "./../API/IKUtils";
//
export default class IKMailer {
  constructor(_defaultFrom, region) {
    this.from = _defaultFrom;
    this.templateDefaultFile = 'html';
    //setup local stuff
    let configObj = {region: region};
    if (Utils.isOffline()) configObj = {region: region, accessKeyId: process.env.AWS_ACCESS_KEY_ID, secretAccessKey: process.env.AWS_SECRET_ACCESS_KEY};
    AWS.config.update(configObj);
    //
    this.transporter = nodemailer.createTransport({
      SES: new AWS.SES({ apiVersion: "2010-12-01" })
    });
  }

  //to can be an array or just one address
  async sendTemplatedEmail(_to, _templates, _data, _optionalCC, _optionalAttachments) {
    //Generate emails
    const email = new Email({
      message: {
        from: this.from,
        to: _to,
        ...(_optionalAttachments ? {attachments: _optionalAttachments} : {}),
        ...(_optionalCC ? {cc: _optionalCC} : {})
      },
      transport: this.transporter,
      send: true,
      juiceResources: {
        webResources: {
          images: true
        }
      }
    });
    //
    let resp = null;
    try {
      const choosenTemplate = await this._chooseTemplate(_templates, _data);
      resp = await email.send({template: choosenTemplate, locals: _data});
      // console.debug('Mailer resp:', resp);
    } catch (e) { console.error('Mailer error:', e); }
    return resp;
  }


  /* private */
  async _chooseTemplate(templates, data) {
    if (Array.isArray(templates)) {
      //For each template check if can render it
      for (let template of templates) {
        if (await this._canRenderTemplate(template, data)) return template;
      }
    } else if (templates) {
      if (await this._canRenderTemplate(templates, data)) return templates;
    } return 'raw'; //default fallback email
  }
  async _canRenderTemplate(template, data) {
    let validRenderResp = null;
    try {
      const email = new Email();
      validRenderResp = await email.render(`${template}/${this.templateDefaultFile}`, data);
    } catch (e) {
      console.log(`Error while checking renderability of email template ${template}`, e);
    } return (validRenderResp != null);
  }
}
